==> v8unpack-0.17.7.tar.gz: v8unpack-0.17.7/tests/test_form802_decoder.py <==
import os
import sys
import unittest

sys.path.append("../../src/")
from v8unpack import helper
from v8unpack.MetaDataObject.versions.Form803 import Form803 as Form
from v8unpack.MetaDataObject.CatalogForm import CatalogForm
from v8unpack.unittest_helper import compare_file, NotEqualLine


class TestDecodeBraceFile(unittest.TestCase):
    def setUp(self) -> None:
        self.current_dir = os.path.dirname(__file__)
        self.data_dir = os.path.join(self.current_dir, 'data', 'form82')
        self.temp_dir = os.path.join(self.data_dir, 'temp')
        self.temp_dir2 = os.path.join(self.data_dir, 'temp2')

    def test_decode_all_raw_data(self):
        test_files = os.listdir(self.data_dir)
        result = ''
        for file_name in test_files:
            if file_name == 'temp':
                continue
            uuid, x = file_name.split('.')
            result += self.decode_raw_data(uuid)
        self.assertEqual('', result)

    def test_decode_file(self):
        uuid = 'form'
        result = self.decode_raw_data(uuid)
        self.assertEqual('', result)

    def decode_raw_data(self, file_name):
        helper.clear_dir(self.temp_dir)
        helper.clear_dir(self.temp_dir2)
        options = dict(version='802')
        # helper.clear_dir(self.temp_dir2)
        Form.decode(self.data_dir, file_name, self.temp_dir, '', options=options)
        temp_dir = os.path.join(self.temp_dir, 'ФормаСписка')
        form = Form(options=options)
        form.encode(temp_dir, file_name, self.temp_dir2, None, [{}])
        problems = ''
        try:
            result = compare_file(
                os.path.join(self.data_dir, file_name),
                os.path.join(self.temp_dir2, file_name),
                problems
            )
        except NotEqualLine as err:
            result = err
        return result

    def test_decode_by_scheme(self):
        from v8unpack.MetaDataObject.schemes.Form import Form

        file_name = '9c80a4da-8f1f-48ae-915c-4227fef8f364'
        data = Form(self.data_dir, file_name).decode()

==> v8unpack-0.19.0.tar.gz: v8unpack-0.19.0/tests/test_form802_decoder.py <==
import os
import sys
import unittest

sys.path.append("../../src/")
from v8unpack import helper
from v8unpack.MetaDataObject.versions.Form803 import Form803 as Form
from v8unpack.MetaDataObject.CatalogForm import CatalogForm
from v8unpack.unittest_helper import compare_file, NotEqualLine


class TestDecodeBraceFile(unittest.TestCase):
    def setUp(self) -> None:
        self.current_dir = os.path.dirname(__file__)
        self.data_dir = os.path.join(self.current_dir, 'data', 'form82')
        self.temp_dir = os.path.join(self.data_dir, 'temp')
        self.temp_dir2 = os.path.join(self.data_dir, 'temp2')

    def test_decode_all_raw_data(self):
        test_files = os.listdir(self.data_dir)
        test_files = ['привязки 1 нет объектов и привязок',
                      'привязки 3 привязки явно убраны',
                      'привязки 4 к форме по горизонтали слева',
                      'привязки 6 к форме по горизонтали справа']
        result = ''
        for file_name in test_files:
            if file_name == 'temp':
                continue
            # uuid, x = file_name.split('.')
            result += self.decode_raw_data(file_name)
        self.assertEqual('', result)

    def test_decode_file(self):
        uuid = 'привязки 3 привязки явно убраны'
        result = self.decode_raw_data(uuid)
        self.assertEqual('', result)

    def decode_raw_data(self, file_name):
        # helper.clear_dir(self.temp_dir)
        # helper.clear_dir(self.temp_dir2)
        options = dict(version='802')
        # helper.clear_dir(self.temp_dir2)
        Form.decode(self.data_dir, file_name, self.temp_dir, '', options=options)
        temp_dir = os.path.join(self.temp_dir, 'ФормаСписка')
        form = Form(options=options)
        form.encode(temp_dir, file_name, self.temp_dir2, None, [{}])
        problems = ''
        try:
            result = compare_file(
                os.path.join(self.data_dir, file_name),
                os.path.join(self.temp_dir2, file_name),
                problems
            )
        except NotEqualLine as err:
            result = err
        return result

    def test_decode_by_scheme(self):
        from v8unpack.MetaDataObject.schemes.Form import Form

        file_name = '9c80a4da-8f1f-48ae-915c-4227fef8f364'
        data = Form(self.data_dir, file_name).decode()
